@@ -24,6 +24,7 @@ import os
 import re
 import shutil
 import tempfile
+import base64
 from concurrent.futures.thread import ThreadPoolExecutor
 from configparser import ConfigParser
 from hashlib import sha256
@@ -50,6 +51,7 @@ from telectron.utils import ainput
 from .dispatcher import Dispatcher
 from .file_id import FileId, FileType, ThumbnailSource
 from .scaffold import Scaffold
+from telectron.raw.types.updates import State
 
 log = logging.getLogger(__name__)
 
@@ -200,7 +202,8 @@ class Client(Methods, Scaffold):
         no_updates: bool = None,
         takeout: bool = None,
         sleep_threshold: int = Session.SLEEP_THRESHOLD,
-        hide_password: bool = False
+        hide_password: bool = False,
+        last_state: str = ''
     ):
         super().__init__()
 
@@ -231,6 +234,8 @@ class Client(Methods, Scaffold):
         self.takeout = takeout
         self.sleep_threshold = sleep_threshold
         self.hide_password = hide_password
+        self.state = self.parse_state(last_state or '')
+        self.cached_me = None
 
         self.executor = ThreadPoolExecutor(self.workers, thread_name_prefix="Handler")
 
@@ -265,6 +270,32 @@ class Client(Methods, Scaffold):
     async def __aexit__(self, *args):
         await self.stop()
 
+    @staticmethod
+    def parse_state(state: str):
+        if len(state) == 0:
+            return
+        string = base64.b64decode(state).decode()
+        version, other = string.split(':', 1)
+        if version == 'v1':
+            pts, qts, date, seq, unread_count = other.split(':')
+            return State(
+                pts=int(pts), 
+                qts=int(qts), 
+                date=int(date), 
+                seq=int(seq), 
+                unread_count=int(unread_count)
+            )
+        else:
+            raise NotImplementedError(f'State version {version} not implemented')
+
+    @staticmethod
+    def unparse_state(s: State):
+        return base64.b64encode(f'v1:{s.pts}:{s.qts}:{s.date}:{s.seq}:{s.unread_count}'.encode()).decode()
+
+    @staticmethod
+    def on_state_update(new_state: str):
+        pass
+
     @property
     def proxy(self):
         return self._proxy
