@@ -775,7 +775,7 @@ def command(commands: Union[str, List[str]], prefixes: Union[str, List[str]] = "
         global username
 
         if username is None:
-            username = (await client.get_me()).username or ""
+            username = client.cached_me.username or ""
 
         text = message.text or message.caption
         message.command = None
