@@ -19,11 +19,13 @@
 from .resolve_peer import ResolvePeer
 from .save_file import SaveFile
 from .send import Send
+from .wait_for import WaitFor
 
 
 class Advanced(
     ResolvePeer,
     SaveFile,
-    Send
+    Send,
+    WaitFor
 ):
     pass
