@@ -984,7 +984,7 @@ class Chat(Object):
 
     @property
     def full_name(self) -> str:
-        """Full_name of the chat if the chat is a user.
+        """Full name of the user
 
         Returns:
             ``str``: On success, str is returned.
